*================== Program: PDI_PROV_STRATIFIED.SAS ====================;
*
*  Description:
*         USES PROC SUMMARY TO CALCULATE OBSERVED RATES FOR
*         PEDIATRIC QUALITY INDICATORS ACROSS STRATIFIERS.
*         PROGRAM USES HOSPID, GPPD01, GPPD02, GPPD08, GPPD10,
*         GPPD11, GPPD12.
*
*             >>> AHRQ QI ICD-10  VERSION 6.0.1 <<<
*	            >>> VERSION DATE SEPT, 2016 <<<
*===================================================================;

*PATHNAME specifies the location of the PDI folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=c:\pathname;                        *<==USER MUST modify;
filename CONTROL "&PATHNAME.\PDI\Programs\PDI_ALL_CONTROL.SAS"; 

%include CONTROL;

 title2 'PROGRAM: PDI_STRATIFIED';
 title3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE STRATIFIED OBSERVED PROVIDER RATES';

 * -------------------------------------------------------------- ;
 * --- PROVIDER LEVEL MEANS ON PEDIATRIC DATA FILE  ------------- ;
 * -------------------------------------------------------------- ;
  * --------------------------------------------------------------- ;
* --- PEDIATRIC QUALITY INDICATOR (PDI) NAMING CONVENTION:      --- ;
* --- THE FIRST LETTER IDENTIFIES THE PEDIATRIC QUALITY         --- ;
* --- INDICATOR AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP") - FROM PDI_ALL_MEASURES
                (P) DENOMINATOR ("POPULATION")
                (O) OBSERVED RATES (T/P)
                (G) MEASURE SPECIFIC STRATIFICATION ("GROUP") 
                    FROM PDI_ALL_MEASURES
* --- THE SECOND LETTER IDENTIFIES THE INDICATOR AS A PROVIDER  --- ;
* --- (P) LEVEL INDICATOR.  THE NEXT TWO CHARACTERS ARE ALWAYS  --- ;
* --- 'PD'. THE LAST TWO DIGITS ARE THE INDICATOR NUMBER.       --- ;
* ----------------------------------------------------------------- ;

 * sumwgt is unassigned using default of weight = 1;
 proc   SUMMARY data=OUTMSR.&OUTFILE_MEAS. missing;
 class  HOSPID GPPD01 GPPD02 GPPD08 GPPD10 GPPD11 GPPD12;
 var    TPPD01 TPPD02 TPPD08 TPPD10 TPPD11 TPPD12;
 output out=&OUTFILE_STRAT.
        sum (TPPD01 TPPD02 TPPD08 TPPD10 TPPD11 TPPD12)=
        sumwgt(TPPD01 TPPD02 TPPD08 TPPD10 TPPD11 TPPD12)=PPPD01 PPPD02 PPPD08 PPPD10 PPPD11 PPPD12
        mean(TPPD01 TPPD02 TPPD08 TPPD10 TPPD11 TPPD12)=OPPD01 OPPD02 OPPD08 OPPD10 OPPD11 OPPD12;
 run;

 proc   Sort data=&OUTFILE_STRAT.;
 by HOSPID GPPD01 GPPD02 GPPD08 GPPD10 GPPD11 GPPD12;
 run;

 data   OUTST.&OUTFILE_STRAT.;
 set    &OUTFILE_STRAT. (where=(_TYPE_ in (1,2,4,8,16,32,65,66,68,72,80,96)))
;

 label
 TPPD01 = 'PDI 01 Accidental Puncture or Laceration Rate (Numerator)'
 TPPD02 = 'PDI 02 Pressure Ulcer Rate (Numerator)'
 TPPD08 = 'PDI 08 Perioperative Hemorrhage or Hematoma Rate (Numerator)'
 TPPD10 = 'PDI 10 Postoperative Sepsis Rate (Numerator)'
 TPPD11 = 'PDI 11 Postoperative Wound Dehiscence Rate (Numerator)'
 TPPD12 = 'PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (Numerator)'
 PPPD01 = 'PDI 01 Accidental Puncture or Laceration Rate (Population)'
 PPPD02 = 'PDI 02 Pressure Ulcer Rate (Population)'
 PPPD08 = 'PDI 08 Perioperative Hemorrhage or Hematoma Rate (Population)'
 PPPD10 = 'PDI 10 Postoperative Sepsis Rate (Population)'
 PPPD11 = 'PDI 11 Postoperative Wound Dehiscence Rate (Population)'
 PPPD12 = 'PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (Population)'
 OPPD01 = 'PDI 01 Accidental Puncture or Laceration Rate (Observed)'
 OPPD02 = 'PDI 02 Pressure Ulcer Rate (Observed)'
 OPPD08 = 'PDI 08 Perioperative Hemorrhage or Hematoma Rate (Observed)'
 OPPD10 = 'PDI 10 Postoperative Sepsis Rate (Observed)'
 OPPD11 = 'PDI 11 Postoperative Wound Dehiscence Rate (Observed)'
 OPPD12 = 'PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (Observed)'
 GPPD01 = 'PDI 01 Accidental Puncture or Laceration Rate (Stratified)'
 GPPD02 = 'PDI 02 Pressure Ulcer Rate (Stratified)'
 GPPD08 = 'PDI 08 Perioperative Hemorrhage or Hematoma Rate (Stratified)'
 GPPD10 = 'PDI 10 Postoperative Sepsis Rate (Stratified)' 
 GPPD11 = 'PDI 11 Postoperative Wound Dehiscence Rate (Stratified)'
 GPPD12 = 'PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (Stratified)'
 _TYPE_ = 'STRATIFICATION LEVEL'
;
 drop _FREQ_ ;

 run;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
 * -------------------------------------------------------------- ;

 proc   Contents data=OUTST.&OUTFILE_STRAT. position;
 run;

 %MACRO MNS(PD,T);

 proc   MEANS data=OUTST.&OUTFILE_STRAT. (where=(_TYPE_ in (&T.))) n nmiss min max mean sum nolabels;
 title4 "SUMMARY OF PROVIDER-LEVEL RATES, PDI &PD.";
 class GPPD&PD.;
 var TPPD&PD. PPPD&PD. OPPD&PD.;
 run;

 %MEND;

 %MNS(01,96);
 %MNS(02,80);
 %MNS(08,72);
 %MNS(10,68);
 %MNS(11,66);
 %MNS(12,65);

 * ---------------------------------------------------------------- ;
 * --- PRINT PROVIDER STRATIFIED MEANS FILE TO SAS OUTPUT --------- ;
 * ---------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT,T1,T2);

 proc   Print data=OUTST.&OUTFILE_STRAT. label SPLIT='*';
 var    HOSPID GPPD&PD. TPPD&PD. PPPD&PD. OPPD&PD. ;
 label HOSPID  = "HOSPID"
       GPPD&PD.   = "GPPD&PD.*(Stratif)"
       TPPD&PD.   = "TPPD&PD.*(Numerator)"
       PPPD&PD.   = "PPPD&PD.*(Denominator)"
       OPPD&PD.   = "OPPD&PD.*(Observed)"
       ;
 format TPPD&PD. PPPD&PD. 13.0 OPPD&PD. 8.6;
 format GPPD&PD. GP&PD.CAT.; 
 title4 "Indicator &PD.: &TEXT";
 where _TYPE_ in (&T1.,&T2.) and GPPD&PD. NE .;
 run;

 %MEND PRT;

 %PRT(01,Accidental Puncture or Laceration Rate,32,96);
 %PRT(02,Pressure Ulcer Rate,16,80);
 %PRT(08,Perioperative Hemorrhage or Hematoma Rate,8,72);
 %PRT(10,Postoperative Sepsis Rate,4,68);
 %PRT(11,Postoperative Wound Dehiscence Rate,2,66);
 %PRT(12,Central Venous Catheter-Related Blood Stream Infection Rate,1,65);

 %END;

 %MEND PRT2;

 %PRT2;

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXTST;

 %IF &TXTSTRAT. = 1  %THEN %DO;

 data _NULL_;
   set OUTST.&OUTFILE_STRAT.;
 file PDTXTSTR lrecl=2000;
 if _N_=1 then do;
 put "PedQI" "," "Hosp Id" "," "Stratif" "," "Numerat" "," "Denomin" "," "Rate" "," "Type";
 end;
 
 if _TYPE_ in (32,96) and GPPD01 NE . then 
 put "01 ," HOSPID 13. "," GPPD01 3. "," TPPD01 7.0 "," PPPD01 13.2 "," OPPD01 12.10 "," _TYPE_ 2.;
 if _TYPE_ in (16,80) and GPPD02 NE . then 
 put "02 ," HOSPID 13. "," GPPD02 3. "," TPPD02 7.0 "," PPPD02 13.2 "," OPPD02 12.10 "," _TYPE_ 2.;
 if _TYPE_ in (8,72) and GPPD08 NE . then 
 put "08 ," HOSPID 13. "," GPPD08 3. "," TPPD08 7.0 "," PPPD08 13.2 "," OPPD08 12.10 "," _TYPE_ 2.;
 if _TYPE_ in (4,68) and GPPD10 NE . then 
 put "10 ," HOSPID 13. "," GPPD10 3. "," TPPD10 7.0 "," PPPD10 13.2 "," OPPD10 12.10 "," _TYPE_ 2.;
 if _TYPE_ in (2,66) and GPPD11 NE . then 
 put "11 ," HOSPID 13. "," GPPD11 3. "," TPPD11 7.0 "," PPPD11 13.2 "," OPPD11 12.10 "," _TYPE_ 2.;
 if _TYPE_ in (1,65) and GPPD12 NE . then 
 put "12 ," HOSPID 13. "," GPPD12 3. "," TPPD12 7.0 "," PPPD12 13.2 "," OPPD12 12.10 "," _TYPE_ 2.;

 ;
 run;

 %END;

 %MEND TEXTST;

 %TEXTST;
